cell_type_DE: Test differential expression of isoforms across cell types

View source: R/cell_type_DE.R

cell_type_DER Documentation

Test differential expression of isoforms across cell types

Description

This function provides a wrapper to compute Differential Expression across multiple cell types on a single-cell dataset, using standard bulk tools edgeR and DESeq2 and ZINBWaVE weights, as described by Van den Berge et al. (see references below).

Usage

cell_type_DE(
  data,
  mode = c("edgeR", "DESeq2", "both"),
  compute_weights = TRUE,
  AdjPvalue = NULL,
  maxFC = NULL,
  offset = NULL
)

Arguments

data

A SingleCellExperiment (SCE) object including isoform-level counts on the assay() slot and a cell_type column indicating cell type correspondence in the colData() slot.

mode

A character value indicating whether "edgeR", "DESeq2" or "both" DE methods are to be run.

compute_weights

A logical value. If TRUE, cell-level weights will be computed using ZINBWaVE (see zinbwave). Alternatively, weights may be pre-computed and stored in the weights() slot in the SCE object.

AdjPvalue

A numeric value. If provided, filtering of DE results by adjusted p-value is enabled.

maxFC

A numeric value. If provided, filtering of DE results by maximum fold-change (maxFC) across cell types is enabled. Note that FC filter is based on edgeR's output (FC between all conditions), and therefore this option requires modes "edgeR" or "both" to be enabled.

offset

Optionally, a matrix containing offset information to be considered for bias correction in edgeR and/or DESeq2 DE tests.

Value

If mode = "both", a named list of length 2 containing the results (filtered or not, depending on whether AdjPvalue and maxFC are provided) of testing Differential Expression using edgeR and DESeq2. If maxFC is provided, columns max_FC and max_log2FC are added to the results tables. If the mode argument was used to select only one method, the function returns a data.frame object containing the results table obtained by that method.

References

\insertRef

Robinson2009acorde

\insertRef

Love2014acorde

\insertRef

VandenBerge2018acorde


ConesaLab/acorde documentation built on Feb. 25, 2024, 4:16 a.m.