| cell_type_DE | R Documentation |
This function provides a wrapper to compute Differential Expression across multiple cell types on a single-cell dataset, using standard bulk tools edgeR and DESeq2 and ZINBWaVE weights, as described by Van den Berge et al. (see references below).
cell_type_DE(
data,
mode = c("edgeR", "DESeq2", "both"),
compute_weights = TRUE,
AdjPvalue = NULL,
maxFC = NULL,
offset = NULL
)
data |
A |
mode |
A character value indicating whether |
compute_weights |
A logical value. If |
AdjPvalue |
A numeric value. If provided, filtering of DE results by adjusted p-value is enabled. |
maxFC |
A numeric value. If provided, filtering of DE results by
maximum fold-change (maxFC) across cell types is enabled. Note that FC filter
is based on edgeR's output (FC between all conditions), and therefore this
option requires modes |
offset |
Optionally, a matrix containing offset information to be considered for bias correction in edgeR and/or DESeq2 DE tests. |
If mode = "both", a named list of length 2 containing the results
(filtered or not, depending on whether AdjPvalue and maxFC are
provided) of testing Differential Expression using edgeR and DESeq2. If
maxFC is provided, columns max_FC and max_log2FC are added
to the results tables. If the mode argument was used to select only
one method, the function returns a data.frame object containing the results
table obtained by that method.
Robinson2009acorde
\insertRefLove2014acorde
\insertRefVandenBerge2018acorde
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.